@@ -1,5 +1,5 @@
 # This file is part of the markdown-svgbob project
-# https://gitlab.com/mbarkhau/markdown-svgbob
+# https://github.com/mbarkhau/markdown-svgbob
 #
 # Copyright (c) 2019-2021 Manuel Barkhau (mbarkhau@gmail.com) - MIT License
 # SPDX-License-Identifier: MIT
@@ -278,7 +278,7 @@ class SvgbobPostprocessor(Postprocessor):
                         text = text.replace(wrapped_marker, img)
                     else:
                         text = text.replace(marker_tag, img)
-            else:
+            elif 'class="toc"' not in text:
                 logger.warning(f"SvgbobPostprocessor couldn't find: {marker_tag}")
 
         return text
